@@ -818,7 +818,8 @@ rasch.copula3 <- function( dat , itemcluster , dims=NULL ,
 	
 	res <- list( "N.itemclusters" = CC , "item" = item , "iter" = iterend , "dev" = dev ,
 					"delta" = delta , "b" = b , "a" = a , "mu" = mu , "sigma" = sigma , 
-					"alpha1"=alpha1 , "alpha2"=alpha2 , "ic" = ic , "theta.k" = theta.k , "deviance" = dev ,
+					"alpha1"=alpha1 , "alpha2"=alpha2 , "ic" = ic , "theta.k" = theta.k , 
+					"pi.k"= wgt.theta , "deviance" = dev ,
 					"pattern" = pattern	 , "person" = person ,
 					"datalist" = datalist	, "EAP.Rel" = EAP.Rel	,
 					"copula.type" = copula.type	, "summary.delta" = summary.delta ,
